
AS_ANSI = <<-ANSI.chomp
\e[47m                                                          \e[m\n\e[47m                                                          \e[m\n\e[47m                                                          \e[m\n\e[47m                                                          \e[m\n\e[47m        \e[40m              \e[47m  \e[40m      \e[47m      \e[40m              \e[47m        \e[m\n\e[47m        \e[40m  \e[47m          \e[40m  \e[47m  \e[40m  \e[47m          \e[40m  \e[47m          \e[40m  \e[47m        \e[m\n\e[47m        \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m  \e[40m  \e[47m  \e[40m    \e[47m    \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m        \e[m\n\e[47m        \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m    \e[40m        \e[47m  \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m        \e[m\n\e[47m        \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m          \e[40m  \e[47m  \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m        \e[m\n\e[47m        \e[40m  \e[47m          \e[40m  \e[47m  \e[40m    \e[47m        \e[40m  \e[47m          \e[40m  \e[47m        \e[m\n\e[47m        \e[40m              \e[47m  \e[40m  \e[47m  \e[40m  \e[47m  \e[40m  \e[47m  \e[40m              \e[47m        \e[m\n\e[47m                        \e[40m      \e[47m                            \e[m\n\e[47m            \e[40m      \e[47m  \e[40m  \e[47m  \e[40m      \e[47m  \e[40m        \e[47m    \e[40m      \e[47m        \e[m\n\e[47m            \e[40m  \e[47m  \e[40m    \e[47m    \e[40m  \e[47m      \e[40m    \e[47m  \e[40m  \e[47m  \e[40m  \e[47m    \e[40m  \e[47m        \e[m\n\e[47m        \e[40m        \e[47m  \e[40m    \e[47m  \e[40m    \e[47m  \e[40m      \e[47m    \e[40m  \e[47m    \e[40m  \e[47m          \e[m\n\e[47m            \e[40m  \e[47m    \e[40m  \e[47m    \e[40m  \e[47m  \e[40m                    \e[47m          \e[m\n\e[47m              \e[40m  \e[47m  \e[40m    \e[47m                  \e[40m    \e[47m              \e[m\n\e[47m                        \e[40m  \e[47m  \e[40m  \e[47m  \e[40m  \e[47m          \e[40m  \e[47m  \e[40m  \e[47m        \e[m\n\e[47m        \e[40m              \e[47m      \e[40m      \e[47m    \e[40m  \e[47m  \e[40m  \e[47m  \e[40m  \e[47m          \e[m\n\e[47m        \e[40m  \e[47m          \e[40m  \e[47m    \e[40m  \e[47m  \e[40m  \e[47m    \e[40m  \e[47m    \e[40m    \e[47m            \e[m\n\e[47m        \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m  \e[40m  \e[47m  \e[40m    \e[47m    \e[40m    \e[47m      \e[40m  \e[47m          \e[m\n\e[47m        \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m  \e[40m    \e[47m  \e[40m  \e[47m  \e[40m  \e[47m  \e[40m  \e[47m                  \e[m\n\e[47m        \e[40m  \e[47m  \e[40m      \e[47m  \e[40m  \e[47m  \e[40m    \e[47m    \e[40m  \e[47m  \e[40m  \e[47m  \e[40m      \e[47m            \e[m\n\e[47m        \e[40m  \e[47m          \e[40m  \e[47m      \e[40m    \e[47m      \e[40m    \e[47m  \e[40m  \e[47m            \e[m\n\e[47m        \e[40m              \e[47m              \e[40m  \e[47m  \e[40m  \e[47m  \e[40m    \e[47m          \e[m\n\e[47m                                                          \e[m\n\e[47m                                                          \e[m\n\e[47m                                                          \e[m\n\e[47m                                                          \e[m\n
ANSI

AS_SVG= <<-SVG.chomp
<?xml version="1.0" standalone="yes"?>
<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:ev="http://www.w3.org/2001/xml-events" width="231" height="231" shape-rendering="crispEdges">
<rect width="11" height="11" x="0" y="0" style="fill:#000"/><rect width="11" height="11" x="11" y="0" style="fill:#000"/><rect width="11" height="11" x="22" y="0" style="fill:#000"/><rect width="11" height="11" x="33" y="0" style="fill:#000"/><rect width="11" height="11" x="44" y="0" style="fill:#000"/><rect width="11" height="11" x="55" y="0" style="fill:#000"/><rect width="11" height="11" x="66" y="0" style="fill:#000"/><rect width="11" height="11" x="88" y="0" style="fill:#000"/><rect width="11" height="11" x="110" y="0" style="fill:#000"/><rect width="11" height="11" x="132" y="0" style="fill:#000"/><rect width="11" height="11" x="154" y="0" style="fill:#000"/><rect width="11" height="11" x="165" y="0" style="fill:#000"/><rect width="11" height="11" x="176" y="0" style="fill:#000"/><rect width="11" height="11" x="187" y="0" style="fill:#000"/><rect width="11" height="11" x="198" y="0" style="fill:#000"/><rect width="11" height="11" x="209" y="0" style="fill:#000"/><rect width="11" height="11" x="220" y="0" style="fill:#000"/>
<rect width="11" height="11" x="0" y="11" style="fill:#000"/><rect width="11" height="11" x="66" y="11" style="fill:#000"/><rect width="11" height="11" x="121" y="11" style="fill:#000"/><rect width="11" height="11" x="132" y="11" style="fill:#000"/><rect width="11" height="11" x="154" y="11" style="fill:#000"/><rect width="11" height="11" x="220" y="11" style="fill:#000"/>
<rect width="11" height="11" x="0" y="22" style="fill:#000"/><rect width="11" height="11" x="22" y="22" style="fill:#000"/><rect width="11" height="11" x="33" y="22" style="fill:#000"/><rect width="11" height="11" x="44" y="22" style="fill:#000"/><rect width="11" height="11" x="66" y="22" style="fill:#000"/><rect width="11" height="11" x="88" y="22" style="fill:#000"/><rect width="11" height="11" x="121" y="22" style="fill:#000"/><rect width="11" height="11" x="132" y="22" style="fill:#000"/><rect width="11" height="11" x="154" y="22" style="fill:#000"/><rect width="11" height="11" x="176" y="22" style="fill:#000"/><rect width="11" height="11" x="187" y="22" style="fill:#000"/><rect width="11" height="11" x="198" y="22" style="fill:#000"/><rect width="11" height="11" x="220" y="22" style="fill:#000"/>
<rect width="11" height="11" x="0" y="33" style="fill:#000"/><rect width="11" height="11" x="22" y="33" style="fill:#000"/><rect width="11" height="11" x="33" y="33" style="fill:#000"/><rect width="11" height="11" x="44" y="33" style="fill:#000"/><rect width="11" height="11" x="66" y="33" style="fill:#000"/><rect width="11" height="11" x="99" y="33" style="fill:#000"/><rect width="11" height="11" x="154" y="33" style="fill:#000"/><rect width="11" height="11" x="176" y="33" style="fill:#000"/><rect width="11" height="11" x="187" y="33" style="fill:#000"/><rect width="11" height="11" x="198" y="33" style="fill:#000"/><rect width="11" height="11" x="220" y="33" style="fill:#000"/>
<rect width="11" height="11" x="0" y="44" style="fill:#000"/><rect width="11" height="11" x="22" y="44" style="fill:#000"/><rect width="11" height="11" x="33" y="44" style="fill:#000"/><rect width="11" height="11" x="44" y="44" style="fill:#000"/><rect width="11" height="11" x="66" y="44" style="fill:#000"/><rect width="11" height="11" x="88" y="44" style="fill:#000"/><rect width="11" height="11" x="99" y="44" style="fill:#000"/><rect width="11" height="11" x="110" y="44" style="fill:#000"/><rect width="11" height="11" x="154" y="44" style="fill:#000"/><rect width="11" height="11" x="176" y="44" style="fill:#000"/><rect width="11" height="11" x="187" y="44" style="fill:#000"/><rect width="11" height="11" x="198" y="44" style="fill:#000"/><rect width="11" height="11" x="220" y="44" style="fill:#000"/>
<rect width="11" height="11" x="0" y="55" style="fill:#000"/><rect width="11" height="11" x="66" y="55" style="fill:#000"/><rect width="11" height="11" x="99" y="55" style="fill:#000"/><rect width="11" height="11" x="121" y="55" style="fill:#000"/><rect width="11" height="11" x="154" y="55" style="fill:#000"/><rect width="11" height="11" x="220" y="55" style="fill:#000"/>
<rect width="11" height="11" x="0" y="66" style="fill:#000"/><rect width="11" height="11" x="11" y="66" style="fill:#000"/><rect width="11" height="11" x="22" y="66" style="fill:#000"/><rect width="11" height="11" x="33" y="66" style="fill:#000"/><rect width="11" height="11" x="44" y="66" style="fill:#000"/><rect width="11" height="11" x="55" y="66" style="fill:#000"/><rect width="11" height="11" x="66" y="66" style="fill:#000"/><rect width="11" height="11" x="88" y="66" style="fill:#000"/><rect width="11" height="11" x="110" y="66" style="fill:#000"/><rect width="11" height="11" x="132" y="66" style="fill:#000"/><rect width="11" height="11" x="154" y="66" style="fill:#000"/><rect width="11" height="11" x="165" y="66" style="fill:#000"/><rect width="11" height="11" x="176" y="66" style="fill:#000"/><rect width="11" height="11" x="187" y="66" style="fill:#000"/><rect width="11" height="11" x="198" y="66" style="fill:#000"/><rect width="11" height="11" x="209" y="66" style="fill:#000"/><rect width="11" height="11" x="220" y="66" style="fill:#000"/>
<rect width="11" height="11" x="88" y="77" style="fill:#000"/><rect width="11" height="11" x="99" y="77" style="fill:#000"/><rect width="11" height="11" x="110" y="77" style="fill:#000"/><rect width="11" height="11" x="121" y="77" style="fill:#000"/><rect width="11" height="11" x="132" y="77" style="fill:#000"/>
<rect width="11" height="11" x="55" y="88" style="fill:#000"/><rect width="11" height="11" x="66" y="88" style="fill:#000"/><rect width="11" height="11" x="99" y="88" style="fill:#000"/><rect width="11" height="11" x="121" y="88" style="fill:#000"/><rect width="11" height="11" x="132" y="88" style="fill:#000"/><rect width="11" height="11" x="154" y="88" style="fill:#000"/><rect width="11" height="11" x="176" y="88" style="fill:#000"/><rect width="11" height="11" x="198" y="88" style="fill:#000"/><rect width="11" height="11" x="220" y="88" style="fill:#000"/>
<rect width="11" height="11" x="0" y="99" style="fill:#000"/><rect width="11" height="11" x="22" y="99" style="fill:#000"/><rect width="11" height="11" x="44" y="99" style="fill:#000"/><rect width="11" height="11" x="110" y="99" style="fill:#000"/><rect width="11" height="11" x="121" y="99" style="fill:#000"/><rect width="11" height="11" x="132" y="99" style="fill:#000"/><rect width="11" height="11" x="154" y="99" style="fill:#000"/><rect width="11" height="11" x="176" y="99" style="fill:#000"/><rect width="11" height="11" x="198" y="99" style="fill:#000"/><rect width="11" height="11" x="209" y="99" style="fill:#000"/>
<rect width="11" height="11" x="0" y="110" style="fill:#000"/><rect width="11" height="11" x="66" y="110" style="fill:#000"/><rect width="11" height="11" x="88" y="110" style="fill:#000"/><rect width="11" height="11" x="99" y="110" style="fill:#000"/><rect width="11" height="11" x="121" y="110" style="fill:#000"/><rect width="11" height="11" x="154" y="110" style="fill:#000"/><rect width="11" height="11" x="176" y="110" style="fill:#000"/><rect width="11" height="11" x="209" y="110" style="fill:#000"/>
<rect width="11" height="11" x="22" y="121" style="fill:#000"/><rect width="11" height="11" x="44" y="121" style="fill:#000"/><rect width="11" height="11" x="55" y="121" style="fill:#000"/><rect width="11" height="11" x="77" y="121" style="fill:#000"/><rect width="11" height="11" x="110" y="121" style="fill:#000"/><rect width="11" height="11" x="121" y="121" style="fill:#000"/><rect width="11" height="11" x="132" y="121" style="fill:#000"/><rect width="11" height="11" x="143" y="121" style="fill:#000"/><rect width="11" height="11" x="154" y="121" style="fill:#000"/><rect width="11" height="11" x="176" y="121" style="fill:#000"/><rect width="11" height="11" x="187" y="121" style="fill:#000"/><rect width="11" height="11" x="198" y="121" style="fill:#000"/><rect width="11" height="11" x="209" y="121" style="fill:#000"/>
<rect width="11" height="11" x="22" y="132" style="fill:#000"/><rect width="11" height="11" x="33" y="132" style="fill:#000"/><rect width="11" height="11" x="44" y="132" style="fill:#000"/><rect width="11" height="11" x="66" y="132" style="fill:#000"/><rect width="11" height="11" x="88" y="132" style="fill:#000"/><rect width="11" height="11" x="99" y="132" style="fill:#000"/><rect width="11" height="11" x="121" y="132" style="fill:#000"/><rect width="11" height="11" x="143" y="132" style="fill:#000"/><rect width="11" height="11" x="154" y="132" style="fill:#000"/><rect width="11" height="11" x="187" y="132" style="fill:#000"/><rect width="11" height="11" x="209" y="132" style="fill:#000"/><rect width="11" height="11" x="220" y="132" style="fill:#000"/>
<rect width="11" height="11" x="88" y="143" style="fill:#000"/><rect width="11" height="11" x="121" y="143" style="fill:#000"/><rect width="11" height="11" x="132" y="143" style="fill:#000"/><rect width="11" height="11" x="143" y="143" style="fill:#000"/><rect width="11" height="11" x="154" y="143" style="fill:#000"/><rect width="11" height="11" x="198" y="143" style="fill:#000"/><rect width="11" height="11" x="209" y="143" style="fill:#000"/><rect width="11" height="11" x="220" y="143" style="fill:#000"/>
<rect width="11" height="11" x="0" y="154" style="fill:#000"/><rect width="11" height="11" x="11" y="154" style="fill:#000"/><rect width="11" height="11" x="22" y="154" style="fill:#000"/><rect width="11" height="11" x="33" y="154" style="fill:#000"/><rect width="11" height="11" x="44" y="154" style="fill:#000"/><rect width="11" height="11" x="55" y="154" style="fill:#000"/><rect width="11" height="11" x="66" y="154" style="fill:#000"/><rect width="11" height="11" x="99" y="154" style="fill:#000"/><rect width="11" height="11" x="154" y="154" style="fill:#000"/><rect width="11" height="11" x="165" y="154" style="fill:#000"/><rect width="11" height="11" x="187" y="154" style="fill:#000"/><rect width="11" height="11" x="209" y="154" style="fill:#000"/>
<rect width="11" height="11" x="0" y="165" style="fill:#000"/><rect width="11" height="11" x="66" y="165" style="fill:#000"/><rect width="11" height="11" x="88" y="165" style="fill:#000"/><rect width="11" height="11" x="99" y="165" style="fill:#000"/><rect width="11" height="11" x="110" y="165" style="fill:#000"/><rect width="11" height="11" x="121" y="165" style="fill:#000"/><rect width="11" height="11" x="165" y="165" style="fill:#000"/><rect width="11" height="11" x="176" y="165" style="fill:#000"/><rect width="11" height="11" x="187" y="165" style="fill:#000"/><rect width="11" height="11" x="198" y="165" style="fill:#000"/>
<rect width="11" height="11" x="0" y="176" style="fill:#000"/><rect width="11" height="11" x="22" y="176" style="fill:#000"/><rect width="11" height="11" x="33" y="176" style="fill:#000"/><rect width="11" height="11" x="44" y="176" style="fill:#000"/><rect width="11" height="11" x="66" y="176" style="fill:#000"/><rect width="11" height="11" x="99" y="176" style="fill:#000"/><rect width="11" height="11" x="110" y="176" style="fill:#000"/><rect width="11" height="11" x="121" y="176" style="fill:#000"/><rect width="11" height="11" x="132" y="176" style="fill:#000"/><rect width="11" height="11" x="143" y="176" style="fill:#000"/><rect width="11" height="11" x="209" y="176" style="fill:#000"/>
<rect width="11" height="11" x="0" y="187" style="fill:#000"/><rect width="11" height="11" x="22" y="187" style="fill:#000"/><rect width="11" height="11" x="33" y="187" style="fill:#000"/><rect width="11" height="11" x="44" y="187" style="fill:#000"/><rect width="11" height="11" x="66" y="187" style="fill:#000"/><rect width="11" height="11" x="121" y="187" style="fill:#000"/><rect width="11" height="11" x="132" y="187" style="fill:#000"/><rect width="11" height="11" x="154" y="187" style="fill:#000"/><rect width="11" height="11" x="176" y="187" style="fill:#000"/><rect width="11" height="11" x="187" y="187" style="fill:#000"/>
<rect width="11" height="11" x="0" y="198" style="fill:#000"/><rect width="11" height="11" x="22" y="198" style="fill:#000"/><rect width="11" height="11" x="33" y="198" style="fill:#000"/><rect width="11" height="11" x="44" y="198" style="fill:#000"/><rect width="11" height="11" x="66" y="198" style="fill:#000"/><rect width="11" height="11" x="110" y="198" style="fill:#000"/><rect width="11" height="11" x="121" y="198" style="fill:#000"/><rect width="11" height="11" x="143" y="198" style="fill:#000"/><rect width="11" height="11" x="176" y="198" style="fill:#000"/><rect width="11" height="11" x="209" y="198" style="fill:#000"/><rect width="11" height="11" x="220" y="198" style="fill:#000"/>
<rect width="11" height="11" x="0" y="209" style="fill:#000"/><rect width="11" height="11" x="66" y="209" style="fill:#000"/><rect width="11" height="11" x="187" y="209" style="fill:#000"/><rect width="11" height="11" x="198" y="209" style="fill:#000"/>
<rect width="11" height="11" x="0" y="220" style="fill:#000"/><rect width="11" height="11" x="11" y="220" style="fill:#000"/><rect width="11" height="11" x="22" y="220" style="fill:#000"/><rect width="11" height="11" x="33" y="220" style="fill:#000"/><rect width="11" height="11" x="44" y="220" style="fill:#000"/><rect width="11" height="11" x="55" y="220" style="fill:#000"/><rect width="11" height="11" x="66" y="220" style="fill:#000"/><rect width="11" height="11" x="110" y="220" style="fill:#000"/><rect width="11" height="11" x="121" y="220" style="fill:#000"/><rect width="11" height="11" x="209" y="220" style="fill:#000"/>
</svg>
SVG

AS_BASIC= <<-STR
XXXXXXXOOOXOXOOXXXOOOOXXXXXXX
XOOOOOXOOXXXXXOOXOXOOOXOOOOOX
XOXXXOXOOOOXOXOOOOOXOOXOXXXOX
XOXXXOXOOXXXOOXOXXXOOOXOXXXOX
XOXXXOXOXXXOOXOOXOOXOOXOXXXOX
XOOOOOXOOOXXOOXXOXXXXOXOOOOOX
XXXXXXXOXOXOXOXOXOXOXOXXXXXXX
OOOOOOOOXXXOXXOXXOOOXOOOOOOOO
OOXXOOXXXOOXOXOXOOXXOXXOXOOOO
XXOOXXOOXOXXXOOOOOXOXXOXOXXOX
XOXOOXXXXXOXXOOXXOXXXXXXXXOXO
OOOOOOOXXOOOXOOOOXXOXXOXXOOOX
XXXOXXXOXOOXOXOOOXOXOXOOOOXXX
XOXXXXOOXOOOXXOXXOOXOOXXOXXOX
XOOXXXXXOOXOOOOOOXXXXOXOXXOXX
OOOOOOOXXXOXXOXOXOXOOOOOOXOOX
XOOOXOXOXXXXXOXOOXXXOOOOOXOOO
OOOXOXOXOOOOOOOXOOXXOXXOOOXOO
XOXXOOXOXXOOXXOXOXOOXOXXXXOOO
OOXXXXOXOXXXXXXOXOXOXXXXOOXXX
OXOXXOXXOXXXOOOXXXOXXXXXXXOXO
OOOOOOOOXOXOXOOXOOXXXOOOXXOXX
XXXXXXXOXOXOOOOXXOOXXOXOXOXXO
XOOOOOXOOOXOOXOXXOXOXOOOXOOOO
XOXXXOXOOXOOOXXXOOOOXXXXXXXOX
XOXXXOXOXXXXOXOOXXXXOXOOXXOOO
XOXXXOXOXOOOXOOXOOOXXOOOOXXOX
XOOOOOXOOXXOXXOOOOOOOOXOXXXXO
XXXXXXXOOOXXXXOOOOXXOOXXOOXXO
STR

AS_HTML= <<-HTML.chomp
<table><tr><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td></tr><tr><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td></tr><tr><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td></tr><tr><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td></tr><tr><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td></tr><tr><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td></tr><tr><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td></tr><tr><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td></tr><tr><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td></tr><tr><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td></tr><tr><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td></tr><tr><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="black"></td></tr><tr><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="black"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td><td class="white"></td></tr></table>
HTML
